"""
Created on Wed Sep 3rd 2020

@author: Shikha, Ramon, Eline

This is the parameter sensitiviy analysis for the model with toxin equation
(model1_gut)

"""


import matplotlib.pyplot as plt
from model1_parameters import *
import numpy as np
from model1_gut import system_toxin
from model1_web_functions import perform_psa

if __name__ == "__main__":

    # Parameter list of easy labelling   
    param_names = 'Growth rate','Carrying capacity','Contact rate constant', 'Lysis rate', 'Phage death rate', 'Virus replication factor', 'Cry degradation rate', 'Toxin production per cell','RNA degradation rate', 'Initial susceptible cell concentration'
    
    # Creating an list of paramters that will be tested in this code
    param_list = np.array([mu_gut, c_gut, ep_gut, lambda_gut, gamma_gut, beta_gut, eta1_gut, alpha_gut,eta2_gut])
    psa = perform_psa(system_toxin, param_list, [0.2, 5.2, 0.2], [t0,tend,20000], [X_s0_gut, X_i0_gut, P0_gut, T10_gut,T20_gut], 'BDF', xs0_equals_C=False )
    
    #Convert to matrix and change units for eay plotting
    Max_T =psa[0]
    Max_T_micro = Max_T*mass_T
    #Integ_T_micro = psa[1]*mass_T
    Max_RNA = psa[3]
    
    # Plot the maximum concentrations of toxin 
    plot = plt.figure(1,figsize=(500/96, 500/96), dpi=96)
    
    ax0 = plt.subplot(211)
    for i in range(len(param_names)):
        if param_names[i] == 'RNA degradation rate' or param_names[i] == 'Toxin production per cell' or param_names[i] == 'Initial susceptible cell concentration':
            continue
        ax0.plot(psa[2]*100, Max_T_micro[i], label = param_names[i])    
    ax0.legend(loc="upper left", bbox_to_anchor=[1, 1.1],
                     ncol=1)
    plt.xlabel('Value of parameter compared to original value (%)', fontsize=11)
    plt.ylabel('Max $T_C$ (\u03BCg/ml)', fontsize=11)
    ax0.set_title(r"a.", pad=20, fontsize=17, x=-.2)
    
    ax1 = plt.subplot(212)
    for i in range(len(param_names)):
        if param_names[i] == 'Toxin production per cell' or param_names[i] == 'Initial susceptible cell concentration':
            plt.plot(psa[2]*100, Max_T_micro[i], label = param_names[i])   
    ax1.legend(loc="upper left", bbox_to_anchor=[1, 1.05],
                     ncol=1)
    plt.xlabel('Value of parameter compared to original value (%)', fontsize=11)
    plt.ylabel('Max $T_C$ (\u03BCg/ml)', fontsize=11)
    ax1.set_title(r"b.", pad=20, fontsize=17, x=-.2)
    
    plt.savefig("Model 1 web max TC", bbox_inches='tight')
    plt.subplots_adjust(wspace=0.4, hspace=0.7)    
    plt.show()
    
    # 2 Max TR
    plot = plt.figure(2,figsize=(500/96, 500/96), dpi=96)
    
    ax0 = plt.subplot(211)
    for i in range(len(param_names)):
        if param_names[i] == 'Cry degradation rate' or param_names[i] =='Lysis rate' or param_names[i] =='RNA degradation rate' or param_names[i] == 'Toxin production per cell' or param_names[i] == 'Initial susceptible cell concentration':
            continue
        ax0.plot(psa[2]*100, Max_RNA[i], label = param_names[i])    
    ax0.legend(loc="upper left", bbox_to_anchor=[1, 1.1],
                     ncol=1)
    plt.xlabel('Value of parameter compared to original value (%)', fontsize=11)
    plt.ylabel('Max $T_R$ (number/ml)', fontsize=11)
    ax0.set_title(r"a.", pad=20, fontsize=17, x=-.2)
    
    ax1 = plt.subplot(212)
    for i in range(len(param_names)):
        if param_names[i] =='Lysis rate' or param_names[i] =='RNA degradation rate' or param_names[i] == 'Toxin production per cell' or param_names[i] == 'Initial susceptible cell concentration':
            plt.plot(psa[2]*100, Max_RNA[i], label = param_names[i])   
    ax1.legend(loc="upper left", bbox_to_anchor=[1, 1.05],
                     ncol=1)
    plt.xlabel('Value of parameter compared to original value (%)', fontsize=11)
    plt.ylabel('Max $T_R$ (number/ml))', fontsize=11)
    ax1.set_title(r"b.", pad=20, fontsize=17, x=-.2)
    
    plt.savefig("Model 1 web max TR", bbox_inches='tight')
    plt.subplots_adjust(wspace=0.4, hspace=0.7)    
    plt.show()

    # 3 time to max cry

    plot = plt.figure(3,figsize=(500/96, 500/96), dpi=96)
    
    ax0 = plt.subplot(211)
    for i in range(len(param_names)):
        if param_names[i] == 'RNA degradation rate' or param_names[i] == 'Lysis rate' or param_names[i] == 'Cry degradation rate':
            continue
        ax0.plot(psa[2]*100,psa[4][i], label = param_names[i])    
    ax0.legend(loc="upper left", bbox_to_anchor=[1, 1.1],
                     ncol=1)
    plt.xlabel('Value of parameter compared to original value (%)', fontsize=11)
    plt.ylabel('Time to Max $T_C$ (h)', fontsize=11)
    ax0.set_title(r"a.", pad=20, fontsize=17, x=-.2)
    
    ax1 = plt.subplot(212)
    for i in range(len(param_names)):
        if param_names[i] == 'Lysis rate' or param_names[i] == 'Cry degradation rate':
            plt.plot(psa[2]*100,psa[4][i], label = param_names[i])   
    ax1.legend(loc="upper left", bbox_to_anchor=[1, 1.05],
                     ncol=1)
    plt.xlabel('Value of parameter compared to original value (%)', fontsize=11)
    plt.ylabel('Time to Max $T_C$ (h)', fontsize=11)
    ax1.set_title(r"b.", pad=20, fontsize=17, x=-.2)
    
    plt.savefig("Model 1 web time to max TC", bbox_inches='tight')
    plt.subplots_adjust(wspace=0.4, hspace=0.7)    
    plt.show()
    
    #4 time to max shRNA

    plot = plt.figure(4,figsize=(500/96, 500/96), dpi=96)
    
    ax0 = plt.subplot(211)
    for i in range(len(param_names)):
        if param_names[i] == 'Cry degradation rate' or param_names[i] == 'Lysis rate' or param_names[i] == 'RNA degradation rate':
            continue
        ax0.plot(psa[2]*100,psa[5][i], label = param_names[i])    
    ax0.legend(loc="upper left", bbox_to_anchor=[1, 1.1],
                     ncol=1)
    plt.xlabel('Value of parameter compared to original value (%)', fontsize=11)
    plt.ylabel('Time to Max $T_R$ (h)', fontsize=11)
    ax0.set_title(r"a.", pad=20, fontsize=17, x=-.2)
    
    ax1 = plt.subplot(212)
    for i in range(len(param_names)):
        if param_names[i] == 'Lysis rate' or param_names[i] == 'RNA degradation rate':
            plt.plot(psa[2]*100,psa[5][i], label = param_names[i])   
    ax1.legend(loc="upper left", bbox_to_anchor=[1, 1.05],
                     ncol=1)
    plt.xlabel('Value of parameter compared to original value (%)', fontsize=11)
    plt.ylabel('Time to Max $T_R$ (h)', fontsize=11)
    ax1.set_title(r"b.", pad=20, fontsize=17, x=-.2)
    
    plt.savefig("Model 1 web time to max TR", bbox_inches='tight')
    plt.subplots_adjust(wspace=0.4, hspace=0.7)    
    plt.show()
    
    
    
#    plt.figure(5).clf()
#    plt.figure(5)
#    for i in range(len(param_names)):
#        if param_names[i] == 'Cry degradation rate':
#            continue
#        plt.plot(psa[2]*100,psa[5][i], label = param_names[i])
#    plt.legend(bbox_to_anchor=(1, 1), loc='upper left')
#    plt.xlabel("Value of parameter compared to original value (%)")
#    plt.ylabel("Time to max shRNA conc (t)")
#    plt.title('Time to reach max shRNA conc', y=1.08,x = 0.5)   
#    plt.show() 

#    plt.figure(2).clf()
#    plt.figure(2)
#
#    for i in range(len(param_names)):
#        if param_names[i] == 'RNA degradation rate':
#            continue
#        plt.plot(psa[2]*100, Max_T_micro[i], label = param_names[i])
#    plt.legend(bbox_to_anchor=(1, 1), loc='upper left')
#    plt.xlabel("Value of parameter compared to original value (%)")
#    plt.ylabel("Maximum Cry concentration (\u03BCg/ml)")
#    plt.title('Maximum Cry7Ca1 concentration for all parameters (20-500%)')
#    plt.show() 
#    
#    plt.figure(3).clf()
#    plt.figure(3)
#    for i in range(len(param_names)):
#        if param_names[i] == 'Cry degradation rate'  :
#            continue
#        plt.plot(psa[2]*100,Max_RNA[i],label = param_names[i])
#    plt.legend(bbox_to_anchor=(1, 1), loc='upper left')
#    plt.xlabel("Value of parameter compared to original value (%)")
#    plt.ylabel("Maximum RNA concentration (number/ml)")
#    plt.title(' Maximum shRNA concentration for all parameters (20-500%)',y=1.08,x = 0.5)   
#    plt.show() 
#    
#    plt.figure(4).clf()
#    plt.figure(4)
#    for i in range(len(param_names)):
#        if param_names[i] == 'RNA degradation rate':
#            continue
#        plt.plot(psa[2]*100,psa[4][i], label = param_names[i])
#    plt.legend(bbox_to_anchor=(1, 1), loc='upper left')
#    plt.xlabel("Value of parameter compared to original value (%)")
#    plt.ylabel("Time to max Cry conc (h)")
#    plt.title('Time to reach max Cry conc',y=1.08,x = 0.5)   
#    plt.show() 








